use strict;
use warnings;
use Test::More 0.88;
# This is a relatively nice way to avoid Test::NoWarnings breaking our
# expectations by adding extra tests, without using no_plan.  It also helps
# avoid any other test module that feels introducing random tests, or even
# test plans, is a nice idea.
our $success = 0;
END { $success && done_testing; }

# List our own version used to generate this
my $v = "\nGenerated by Dist::Zilla::Plugin::ReportVersions::Tiny v1.05\n";

eval {                     # no excuses!
    # report our Perl details
    my $want = '5.010';
    my $pv = ($^V || $]);
    $v .= "perl: $pv (wanted $want) on $^O from $^X\n\n";
};
defined($@) and diag("$@");

# Now, our module version dependencies:
sub pmver {
    my ($module, $wanted) = @_;
    $wanted = " (want $wanted)";
    my $pmver;
    eval "require $module;";
    if ($@) {
        if ($@ =~ m/Can't locate .* in \@INC/) {
            $pmver = 'module not found.';
        } else {
            diag("${module}: $@");
            $pmver = 'died during require.';
        }
    } else {
        my $version;
        eval { $version = $module->VERSION; };
        if ($@) {
            diag("${module}: $@");
            $pmver = 'died during VERSION check.';
        } elsif (defined $version) {
            $pmver = "$version";
        } else {
            $pmver = '<undef>';
        }
    }

    # So, we should be good, right?
    return sprintf('%-45s => %-10s%-15s%s', $module, $pmver, $wanted, "\n");
}

eval { $v .= pmver('Carp','any version') };
eval { $v .= pmver('Class::Load','any version') };
eval { $v .= pmver('ExtUtils::MakeMaker','6.30') };
eval { $v .= pmver('File::Find','any version') };
eval { $v .= pmver('File::Temp','any version') };
eval { $v .= pmver('Moose','1.15') };
eval { $v .= pmver('Moose::Exporter','any version') };
eval { $v .= pmver('Moose::Util','any version') };
eval { $v .= pmver('Moose::Util::TypeConstraints','any version') };
eval { $v .= pmver('MooseX::AbstractMethod','0.003') };
eval { $v .= pmver('MooseX::AlwaysCoerce','0.16') };
eval { $v .= pmver('MooseX::AttributeShortcuts','0.015') };
eval { $v .= pmver('MooseX::ClassAttribute','0.26') };
eval { $v .= pmver('MooseX::CurriedDelegation','any version') };
eval { $v .= pmver('MooseX::LazyRequire','0.07') };
eval { $v .= pmver('MooseX::MarkAsMethods','0.14') };
eval { $v .= pmver('MooseX::NewDefaults','0.003') };
eval { $v .= pmver('MooseX::StrictConstructor','0.19') };
eval { $v .= pmver('MooseX::Traits','any version') };
eval { $v .= pmver('MooseX::Types::Combine','any version') };
eval { $v .= pmver('MooseX::Types::Common::Numeric','0.001004') };
eval { $v .= pmver('MooseX::Types::Common::String','0.001004') };
eval { $v .= pmver('MooseX::Types::LoadableClass','0.006') };
eval { $v .= pmver('MooseX::Types::Moose','0.31') };
eval { $v .= pmver('MooseX::Types::Path::Class','0.05') };
eval { $v .= pmver('MooseX::Types::Tied::Hash::IxHash','0.003') };
eval { $v .= pmver('Path::Class','0.24') };
eval { $v .= pmver('Sub::Exporter','any version') };
eval { $v .= pmver('Sub::Install','any version') };
eval { $v .= pmver('Test::Fatal','any version') };
eval { $v .= pmver('Test::Moose','any version') };
eval { $v .= pmver('Test::Moose::More','0.009') };
eval { $v .= pmver('Test::More','0.88') };
eval { $v .= pmver('Test::Requires','any version') };
eval { $v .= pmver('Try::Tiny','0.11') };
eval { $v .= pmver('base','any version') };
eval { $v .= pmver('ok','any version') };
eval { $v .= pmver('strict','any version') };
eval { $v .= pmver('warnings','any version') };


# All done.
$v .= <<'EOT';

Thanks for using my code.  I hope it works for you.
If not, please try and include this output in the bug report.
That will help me reproduce the issue and solve your problem.

EOT

diag($v);
ok(1, "we really didn't test anything, just reporting data");
$success = 1;

# Work around another nasty module on CPAN. :/
no warnings 'once';
$Template::Test::NO_FLUSH = 1;
exit 0;
